@@ -90,6 +90,11 @@ spotGenerateSequentialDesign <- function(spotConfig) {
                                         , largeDesign
                                          , spotConfig));
 	largeDesign <-  as.data.frame(largeDesign[order(spotConfig$seq.largeDesignY,decreasing=FALSE),]);
+	if (spotConfig$seq.predictionModel.func == "spotPredictDualM")
+	{	for (i in 1:length(spotConfig$seq.predictDual$predictions)){
+			spotConfig$seq.predictDual$predictions[[i]] <- as.data.frame(spotConfig$seq.predictDual$predictions[[i]][order(spotConfig$seq.largeDesignY,decreasing=FALSE),])
+		}
+	}	
 	spotConfig$seq.largeDesignY <-  as.data.frame(spotConfig$seq.largeDesignY[order(spotConfig$seq.largeDesignY,decreasing=FALSE),]);
 	##################################################
     ## (2b) If desired, optimize fit returned by prediction model
@@ -150,7 +155,9 @@ spotGenerateSequentialDesign <- function(spotConfig) {
         additionalConfigNumbers <- nrow(largeDesignEvaluated)
 	newCONFIG <- max(mergedData$CONFIG) + 1:additionalConfigNumbers;
 	#use computed config number to link the design point with the model that created it
-	spotConfig$seq.predictDual$links<-rbind(spotConfig$seq.predictDual$links,cbind(newCONFIG, MODEL=rep(spotConfig$seq.predictDual$last,1)))# TODOMZ
+	if (spotConfig$seq.predictionModel.func == "spotPredictDualM"||spotConfig$seq.predictionModel.func == "spotPredictDualB"||spotConfig$seq.predictionModel.func == "spotPredictDual"){
+		spotConfig$seq.predictDual$links<-rbind(spotConfig$seq.predictDual$links,cbind(newCONFIG, MODEL=rep(spotConfig$seq.predictDual$last,1)))# TODOMZ
+	}
 	newD <- cbind(  largeDesignEvaluated
 			, CONFIG = newCONFIG
 			, repeatsInternal = totalWanted
