@@ -71,7 +71,7 @@
 #' 			\item{io.resFileName}{[depends: \code{<configFileName>.res}] name of the .res -file (RESult file) the user written algorithm has to write its results into this file }
 #' 			\item{io.bstFileName}{[depends: \code{<configFileName>.bst}] name of the .bst -file (BeST file) the result-file will be condensed to this file }
 #' 			\item{io.pdfFileName}{[depends: \code{<configFileName>.pdf}] name of the .pdf -file the default report will write its summary of results in this pdf file }
-#' 			\item{io.metaFileName}{[depends: \code{<configFileName>.meta}] name of the .meta -file, a file holding additional parameters for a full-factorial test-field starting several "auto" tasks}
+############ 			\item{io.metaFileName}{[depends: \code{<configFileName>.meta}] name of the .meta -file, a file holding additional parameters for a full-factorial test-field starting several "auto" tasks}
 #' 			\item{io.fbsFileName}{[depends: \code{<configFileName>.bst}] name of the .fbs -file (Final BestSolution file) collects all final best values of all .bst files during a .meta-run }
 #' 			\item{io.verbosity}{[\code{3}] level of verbosity of the programm, 0 should be silent and 3 should produce all output- sometimes just interesting for the developer...}
 #' 			\item{init.design.func}{[\code{"spotCreateDesignLhd"}] name of the function to create an initial design. Please also see the notes SPOT - extensions}
@@ -104,7 +104,7 @@
 #' 			\item{seq.useGradient}{[\code{FALSE}] use gradient information for the prediction model}
 #' 			\item{seq.useCanonicalPath}{[\code{FALSE}] if gradient information is used, start at saddle point and follow the most steeply rising ridge in both directions. Default: start at origin and follow the path of the steepest descent in one direction}
 #' 			\item{seq.useAdaptiveRoi}{[\code{FALSE}] use region of intereset adaptation}
-#' 			\item{meta.keepAllFiles}{[\code{FALSE}] Meta optimization produces lots of temporary files - to keep these files for analysis this switch must be set to TRUE}
+############ 			\item{meta.keepAllFiles}{[\code{FALSE}] Meta optimization produces lots of temporary files - to keep these files for analysis this switch must be set to TRUE}
 #'			\item{report.func}{[\code{"spotReportDefault"}] name of the function providing the report (default="spotReportDefault" Please also see the notes SPOT - extensions }
 #'			\item{report.meta.func}{[\code{"spotReportMetaDefault"}] name of the function providing the report for meta runs, do not use these functions for \code{report.func}.}
 #'			\item{report.path}{[\code{NA} defaults to \code{srcPath}] path where to find the <report.func>.R -file}
@@ -114,6 +114,8 @@
 #' 			\item{report.io.screen}{[\code{FALSE}] report graphics will be printed to screen (FALSE=no, TRUE=yes)}
 #' 			\item{report.io.pdf}{[\code{TRUE}] report graphics will be printed to pdf (FALSE=no, TRUE=yes)}
 #' 			\item{report.io.maxPlots}{[\code{11}] a plot of the performance is continuosly updated, showing the .roi variables in the order given in that file. The graphic is limited to 11 variables. A smaller value here may focus to the relevant variables only}
+#'			\item{meta.list}{[NULL] a list of vectors. Each vector names specific values to be tested in a meta run, for the setting give by the name of the list element. To use it, start SPOT with spotTask="meta"}
+
 #' @references  \code{SPOT} \code{spotPrepare}
 
 ## hint for programmers: 
@@ -208,6 +210,8 @@ spotGetOptions <- function( srcPath=".",configFileName) {
 	#seq.predictionModel.func = "spotPredictLmOptim";
 	seq.predict.subMethod = "none";
 	seq.predictionOpt.func<-NA;
+	seq.predictDual <- NULL;
+	#seq.predictDual$predictions<-NA;
 	seq.useGradient = FALSE
 	seq.useAdaptiveRoi = FALSE
 	seq.useCanonicalPath = FALSE
@@ -239,7 +243,7 @@ spotGetOptions <- function( srcPath=".",configFileName) {
 	## #####################################
 	## ##### Step      meta            #####
 	## #####################################
-	meta.keepAllFiles = FALSE
+	###	meta.keepAllFiles = FALSE
 	## ####################################################################################################
 	## ##### IO related (files for input and output, and variables to specify formatting of IO-files  #####
 	## ####################################################################################################
@@ -347,18 +351,16 @@ spotGetOptions <- function( srcPath=".",configFileName) {
 			, con=stderr());
 	## alg.roi is a table that holds the data of the .roi-file for easy and quick use in some functions 
 	if(file.exists(io.roiFileName)){
-	alg.roi <- read.table( io.roiFileName
-			, sep = io.columnSep
-			, header = TRUE
-			, as.is=TRUE
-			, row.names = 1 #Parameter als Zeilennamen
-		);
+		alg.roi <- spotReadRoi(io.roiFileName,io.columnSep)
 	}
-	else if (userConfFileName=="NULL"){
+	else if (userConfFileName=="NULL"){   #a default roi is used, will be overwritten by any user input
 		alg.roi=data.frame(low=c(-5,0),high=c(10,15),type=c("FLOAT","FLOAT"),row.names=c("VARX1","VARX2"))#Demo, using the branin function
 		spot.fileMode=FALSE;
 	}
-	
+	else
+	{
+		alg.roi=NA;
+	}
 	## at startup, the actual roi (alg.aroi) is the same as the initial roi (alg.roi)
 	alg.aroi <- alg.roi
 	#}
@@ -387,14 +389,7 @@ spotGetOptions <- function( srcPath=".",configFileName) {
 	}
 	if(is.na(report.meta.path)){
 		report.meta.path = srcPath ;
-	}
-	set.seed(paste(format(Sys.time(), "%S"),format(Sys.time(), "%M"),format(Sys.time(), "%H"),sep="")); 
-	if(is.null(spot.seed)){ #Random numbers for seeds, if set to NULL
-		spot.seed =  runif(1)*1000;
-	}
-	if(is.null(alg.seed)){
-		alg.seed =  runif(1)*1000;
-	}
+	}	 
 
 	spotWriteLines(io.verbosity,1,"spotGetOptions finished", con=stderr());
 	## generate a list of ALL the defined variables (default AND user written = sourced by .conf-file!)
